@@ -57,7 +57,9 @@ def model_dict_to_str(
             raise NodeException(f"{field_name=} not in {edgedb_conversion_map=}")
         variable_name = f"{field_name}{random_str(10)}"
         field_str = f"{field_name} := <{type_cast_str}>${variable_name}"
-        if type_cast_str.endswith("::str") and type(val) is dict:
+        if type_cast_str.endswith("::str") and (
+            isinstance(val, dict) or isinstance(val, list)
+        ):
             # for basemodel subfields that should go from dict to str
             val = json.dumps(jsonable_encoder(val))
         if type(val) is set:
